django-jbank
============

Basic Finnish bank file format support for Django projects

Features
========

* Parsing TO files
* Parsing SVM files
* Parsing pain.002.001.03 files
* Generating pain.001.001.03 files
